from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.2'
DESCRIPTION = 'N/A'
LONG_DESCRIPTION = 'N/A'

# Setting up
setup(
    name="miniecs",
    version=VERSION,
    author="Juan Felipe",
    author_email="juanfelipe22103@gmail.com",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'sockets'],
    classifiers=[],
)